summaryrefslogtreecommitdiff
path: root/chromium/net/reporting/reporting_uploader_unittest.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/net/reporting/reporting_uploader_unittest.cc')
-rw-r--r--chromium/net/reporting/reporting_uploader_unittest.cc22
1 files changed, 11 insertions, 11 deletions
diff --git a/chromium/net/reporting/reporting_uploader_unittest.cc b/chromium/net/reporting/reporting_uploader_unittest.cc
index c4147003914..b8b4ed4ac6f 100644
--- a/chromium/net/reporting/reporting_uploader_unittest.cc
+++ b/chromium/net/reporting/reporting_uploader_unittest.cc
@@ -1,4 +1,4 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -13,7 +13,7 @@
#include "base/run_loop.h"
#include "base/test/scoped_feature_list.h"
#include "net/base/features.h"
-#include "net/base/network_isolation_key.h"
+#include "net/base/network_anonymization_key.h"
#include "net/base/schemeful_site.h"
#include "net/cookies/cookie_access_result.h"
#include "net/cookies/cookie_store.h"
@@ -621,14 +621,14 @@ TEST_F(ReportingUploaderTest, DontCacheResponse) {
EXPECT_EQ(2, request_count);
}
-// Create two requests with the same NetworkIsolationKey, and one request with a
-// different one, and make sure only the requests with the same
-// NetworkIsolationKey share a socket.
-TEST_F(ReportingUploaderTest, RespectsNetworkIsolationKey) {
+// Create two requests with the same NetworkAnonymizationKey, and one request
+// with a different one, and make sure only the requests with the same
+// NetworkAnonymizationKey share a socket.
+TEST_F(ReportingUploaderTest, RespectsNetworkAnonymizationKey) {
// While features::kPartitionConnectionsByNetworkIsolationKey is not needed
// for reporting code to respect NetworkIsolationKeys, this test works by
// ensuring that Reporting's NetworkIsolationKey makes it to the socket pool
// layer and is respected there, so this test needs to enable
// kPartitionConnectionsByNetworkIsolationKey.
base::test::ScopedFeatureList feature_list;
feature_list.InitAndEnableFeature(
@@ -720,8 +720,8 @@ TEST_F(ReportingUploaderTest, RespectsNetworkIsolationKey) {
EXPECT_EQ(ReportingUploader::Outcome::SUCCESS, callback1.outcome());
// Start two more requests in parallel. The first started uses a different
// NetworkIsolationKey, so should create a new socket, while the second one
// gets the other socket. Start in parallel to make sure that a new socket
// isn't created just because the first is returned to the socket pool
// asynchronously.
TestUploadCallback callback2;
@@ -621,14 +621,14 @@ TEST_F(ReportingUploaderTest, DontCacheResponse) {
// While features::kPartitionConnectionsByNetworkIsolationKey is not needed
- // for reporting code to respect NetworkIsolationKeys, this test works by
- // ensuring that Reporting's NetworkIsolationKey makes it to the socket pool
- // layer and is respected there, so this test needs to enable
+ // for reporting code to respect NetworkAnonymizationKey, this test works by
+ // ensuring that Reporting's NetworkAnonymizationKey makes it to the socket
+ // pool layer and is respected there, so this test needs to enable
// kPartitionConnectionsByNetworkIsolationKey.
base::test::ScopedFeatureList feature_list;
@@ -720,8 +720,8 @@ TEST_F(ReportingUploaderTest, RespectsNetworkIsolationKey) {
EXPECT_EQ(ReportingUploader::Outcome::SUCCESS, callback1.outcome());
// Start two more requests in parallel. The first started uses a different
- // NetworkIsolationKey, so should create a new socket, while the second one
- // gets the other socket. Start in parallel to make sure that a new socket
+ // NetworkAnonymizationKey, so should create a new socket, while the second
+ // one gets the other socket. Start in parallel to make sure that a new socket
// isn't created just because the first is returned to the socket pool
// asynchronously.